.. _help:

Getting Help with Glue
======================

If you have questions about Glue, we'd love to hear from you. There are several ways to get in touch:

* Ask us on `Twitter <https://twitter.com/glueviz>`_.
* Post a question on the `Glue mailing list <https://groups.google.com/forum/#!forum/glue-viz>`_.
* Join the `Slack channel <https://glueviz.slack.com>`_ - note that you will need to first get an account `here <https://glueviz-slack-invite.herokuapp.com>`_
* For specific bug reports, open a new issue on the `GitHub page <https://github.com/glue-viz/glue/issues>`_.
* Send feedback from Glue itself by selecting ``Send Feedback`` from the help menu.
